package com.mcwl.web.controller.memberCenter;

import cn.hutool.core.bean.BeanUtil;
import com.mcwl.common.core.domain.R;
import com.mcwl.memberCenter.domain.Benefit;
import com.mcwl.memberCenter.domain.dto.BenefitDto;
import com.mcwl.memberCenter.domain.vo.BenefitVo;
import com.mcwl.memberCenter.enums.MemberBenefitTypeEnum;
import com.mcwl.memberCenter.service.BenefitService;
import com.mcwl.memberCenter.service.MemberBenefitService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.List;

/***
 * 权益
 */
@RestController
@RequestMapping("benefit")
@RequiredArgsConstructor
@Api(tags = "会员中心")
public class BenefitController {

    private final BenefitService benefitService;

    /**
     * 权益列表
     */
//    @PreAuthorize("@ss.hasPermi('system:benefit:list')")
    @ApiOperation(value = "权益列表")
    @GetMapping("list")
    public R<List<BenefitVo>> list() {
        List<Benefit> benefitList = benefitService.list();
        List<BenefitVo> benefitVoList = new ArrayList<>();
        for (Benefit benefit : benefitList) {
            BenefitVo benefitVo = BeanUtil.copyProperties(benefit, BenefitVo.class);
            benefitVo.setBenefitType(benefit.getBenefitType().getValue());
            benefitVoList.add(benefitVo);
        }

        return R.ok(benefitVoList);
    }

    /**
     * 添加权益
     */
//    @PreAuthorize("@ss.hasPermi('system:benefit:add')")
    @ApiOperation(value = "添加权益")
    @PostMapping("add")
    public void add(@RequestBody @Valid BenefitDto benefitDto) {

        benefitDto.setId(null);
        Benefit benefit = BeanUtil.copyProperties(benefitDto, Benefit.class);
        benefitService.save(benefit);

    }

    /**
     * 权益详情
     */
//    @PreAuthorize("@ss.hasPermi('system:benefit:query')")
    @ApiOperation(value = "权益详情")
    @GetMapping("detail")
    public R<BenefitVo> detail(Long id) {
        Benefit benefit = benefitService.getById(id);
        BenefitVo benefitVo = BeanUtil.copyProperties(benefit, BenefitVo.class);
        benefitVo.setBenefitType(benefit.getBenefitType().getValue());
        return R.ok(benefitVo);
    }

    /**
     * 修改权益
     */
//    @PreAuthorize("@ss.hasPermi('system:benefit:edit')")
    @ApiOperation(value = "修改权益")
    @PostMapping("update")
    public void update(@RequestBody @Valid BenefitDto benefitDto) {

        Benefit benefit = BeanUtil.copyProperties(benefitDto, Benefit.class);
        benefitService.updateById(benefit);

    }

//    @PreAuthorize("@ss.hasPermi('system:benefit:remove')")
    @ApiOperation(value = "删除权益")
    @GetMapping("delete")
    public void delete(@NotNull(message = "id不能为空") Long id) {
        benefitService.removeById(id);
    }



}
